# Stage Type
SRC = 'SRC'
NOR = 'NOR'
DST = 'DST'

# Pipeline State
STOP = 'STOP'
RUN = 'RUN'
PAUSED = 'PAUSED'

# Inlink Detail: dep_and_pos
DEPENDENCY = 0
POSITION = 1
CONFLATE = 2

# link types
PYOBJ = 'PYOBJ'
BYTES = 'BYTES'